@@ -1,6 +1,6 @@
 /*
   Simple DirectMedia Layer
-  Copyright (C) 1997-2023 Sam Lantinga <slouken@libsdl.org>
+  Copyright (C) 1997-2025 Sam Lantinga <slouken@libsdl.org>
 
   This software is provided 'as-is', without any express or implied
   warranty.  In no event will the authors be held liable for any damages
@@ -26,9 +26,7 @@
 extern "C" {
 #endif
 
-#include "../../SDL_internal.h"
-#include "SDL.h"
-#include "SDL_syswm.h"
+#include "SDL_internal.h"
 #include "SDL_bframebuffer.h"
 
 #ifdef __cplusplus
@@ -39,11 +37,10 @@ extern "C" {
 #include <AppKit.h>
 #include <Cursor.h>
 #include <InterfaceKit.h>
-#if SDL_VIDEO_OPENGL
+#ifdef SDL_VIDEO_OPENGL
 #include <opengl/GLView.h>
 #endif
-#include "SDL_events.h"
-#include "../../main/haiku/SDL_BApp.h"
+#include "../../core/haiku/SDL_BApp.h"
 
 enum WinCommands
 {
@@ -90,7 +87,7 @@ class SDL_BView : public BView
 class SDL_BWin : public BWindow
 {
   public:
-    /* Constructor/Destructor */
+    // Constructor/Destructor
     SDL_BWin(BRect bounds, window_look look, uint32 flags)
         : BWindow(bounds, "Untitled", look, B_NORMAL_WINDOW_FEEL, flags)
     {
@@ -99,7 +96,7 @@ class SDL_BWin : public BWindow
         _cur_view = NULL;
         _SDL_View = NULL;
 
-#if SDL_VIDEO_OPENGL
+#ifdef SDL_VIDEO_OPENGL
         _SDL_GLView = NULL;
         _gl_type = 0;
 #endif
@@ -109,7 +106,7 @@ class SDL_BWin : public BWindow
         _prev_frame = NULL;
         _fullscreen = NULL;
 
-        /* Handle framebuffer stuff */
+        // Handle framebuffer stuff
         _buffer_locker = new BLocker();
         _bitmap = NULL;
     }
@@ -123,14 +120,14 @@ class SDL_BWin : public BWindow
             _SDL_View = NULL;
         }
 
-#if SDL_VIDEO_OPENGL
+#ifdef SDL_VIDEO_OPENGL
         if (_SDL_GLView) {
             if (SDL_Looper->GetCurrentContext() == _SDL_GLView)
                 SDL_Looper->SetCurrentContext(NULL);
             if (_SDL_GLView == _cur_view)
                 RemoveChild(_SDL_GLView);
             _SDL_GLView = NULL;
-            // _SDL_GLView deleted by HAIKU_GL_DeleteContext
+            // _SDL_GLView deleted by HAIKU_GL_DestroyContext
         }
 
 #endif
@@ -138,7 +135,7 @@ class SDL_BWin : public BWindow
 
         delete _prev_frame;
 
-        /* Clean up framebuffer stuff */
+        // Clean up framebuffer stuff
         _buffer_locker->Lock();
         delete _buffer_locker;
     }
@@ -156,9 +153,12 @@ class SDL_BWin : public BWindow
 
     void UpdateCurrentView()
     {
+#ifdef SDL_VIDEO_OPENGL
         if (_SDL_GLView != NULL) {
             SetCurrentView(_SDL_GLView);
-        } else if (_SDL_View != NULL) {
+        } else
+#endif
+        if (_SDL_View != NULL) {
             SetCurrentView(_SDL_View);
         } else {
             SetCurrentView(NULL);
@@ -189,7 +189,7 @@ class SDL_BWin : public BWindow
     }
 
     /* * * * * OpenGL functionality * * * * */
-#if SDL_VIDEO_OPENGL
+#ifdef SDL_VIDEO_OPENGL
     BGLView *CreateGLView(Uint32 gl_flags)
     {
         Lock();
@@ -213,7 +213,7 @@ class SDL_BWin : public BWindow
                 SDL_Looper->SetCurrentContext(NULL);
             _SDL_GLView = NULL;
             UpdateCurrentView();
-            // _SDL_GLView deleted by HAIKU_GL_DeleteContext
+            // _SDL_GLView deleted by HAIKU_GL_DestroyContext
         }
         Unlock();
     }
@@ -225,29 +225,29 @@ class SDL_BWin : public BWindow
 #endif
 
     /* * * * * Event sending * * * * */
-    /* Hook functions */
+    // Hook functions
     virtual void FrameMoved(BPoint origin)
     {
-        /* Post a message to the BApp so that it can handle the window event */
+        // Post a message to the BApp so that it can handle the window event
         BMessage msg(BAPP_WINDOW_MOVED);
         msg.AddInt32("window-x", (int)origin.x);
         msg.AddInt32("window-y", (int)origin.y);
         _PostWindowEvent(msg);
 
-        /* Perform normal hook operations */
+        // Perform normal hook operations
         BWindow::FrameMoved(origin);
     }
 
     void FrameResized(float width, float height)
     {
-        /* Post a message to the BApp so that it can handle the window event */
+        // Post a message to the BApp so that it can handle the window event
         BMessage msg(BAPP_WINDOW_RESIZED);
 
         msg.AddInt32("window-w", (int)width + 1);
         msg.AddInt32("window-h", (int)height + 1);
         _PostWindowEvent(msg);
 
-        /* Perform normal hook operations */
+        // Perform normal hook operations
         BWindow::FrameResized(width, height);
     }
 
@@ -256,13 +256,13 @@ class SDL_BWin : public BWindow
         BMessage msg(BAPP_WINDOW_CLOSE_REQUESTED);
         _PostWindowEvent(msg);
 
-        /* We won't allow a quit unless asked by DestroyWindow() */
+        // We won't allow a quit unless asked by DestroyWindow()
         return false;
     }
 
     void WindowActivated(bool active)
     {
-        BMessage msg(BAPP_KEYBOARD_FOCUS); /* Mouse focus sold separately */
+        BMessage msg(BAPP_KEYBOARD_FOCUS); // Mouse focus sold separately
         msg.AddBool("focusGained", active);
         _PostWindowEvent(msg);
     }
@@ -271,18 +271,18 @@ class SDL_BWin : public BWindow
               float width,
               float height)
     {
-        BMessage msg(BAPP_MAXIMIZE); /* Closest thing to maximization Haiku has */
+        BMessage msg(BAPP_MAXIMIZE); // Closest thing to maximization Haiku has
         _PostWindowEvent(msg);
 
-        /* Before the window zooms, record its size */
+        // Before the window zooms, record its size
         if (!_prev_frame)
             _prev_frame = new BRect(Frame());
 
-        /* Perform normal hook operations */
+        // Perform normal hook operations
         BWindow::Zoom(origin, width, height);
     }
 
-    /* Member functions */
+    // Member functions
     void Show()
     {
         while (IsHidden()) {
@@ -320,12 +320,12 @@ class SDL_BWin : public BWindow
         }
     }
 
-    /* BView message interruption */
+    // BView message interruption
     void DispatchMessage(BMessage *msg, BHandler *target)
     {
-        BPoint where;  /* Used by mouse moved */
-        int32 buttons; /* Used for mouse button events */
-        int32 key;     /* Used for key events */
+        BPoint where;  // Used by mouse moved
+        int32 buttons; // Used for mouse button events
+        int32 key;     // Used for key events
 
         switch (msg->what) {
         case B_MOUSE_MOVED:
@@ -337,13 +337,13 @@ class SDL_BWin : public BWindow
 
         case B_MOUSE_DOWN:
             if (msg->FindInt32("buttons", &buttons) == B_OK) {
-                _MouseButtonEvent(buttons, SDL_PRESSED);
+                _MouseButtonEvent(buttons, true);
             }
             break;
 
         case B_MOUSE_UP:
             if (msg->FindInt32("buttons", &buttons) == B_OK) {
-                _MouseButtonEvent(buttons, SDL_RELEASED);
+                _MouseButtonEvent(buttons, false);
             }
             break;
 
@@ -364,20 +364,20 @@ class SDL_BWin : public BWindow
                 i++;
             }
             if (msg->FindInt32("key", &key) == B_OK) {
-                _KeyEvent((SDL_Scancode)key, &bytes[0], i, SDL_PRESSED);
+                _KeyEvent((SDL_Scancode)key, &bytes[0], i, true);
             }
         } break;
 
-        case B_UNMAPPED_KEY_DOWN: /* modifier keys are unmapped */
+        case B_UNMAPPED_KEY_DOWN: // modifier keys are unmapped
             if (msg->FindInt32("key", &key) == B_OK) {
-                _KeyEvent((SDL_Scancode)key, NULL, 0, SDL_PRESSED);
+                _KeyEvent((SDL_Scancode)key, NULL, 0, true);
             }
             break;
 
         case B_KEY_UP:
-        case B_UNMAPPED_KEY_UP: /* modifier keys are unmapped */
+        case B_UNMAPPED_KEY_UP: // modifier keys are unmapped
             if (msg->FindInt32("key", &key) == B_OK) {
-                _KeyEvent(key, NULL, 0, SDL_RELEASED);
+                _KeyEvent(key, NULL, 0, false);
             }
             break;
 
@@ -387,18 +387,18 @@ class SDL_BWin : public BWindow
                - CTRL+Q to close window (and other shortcuts)
                - PrintScreen to make screenshot into /boot/home
                - etc.. */
-            /* BWindow::DispatchMessage(msg, target); */
+            // BWindow::DispatchMessage(msg, target);
             break;
         }
 
         BWindow::DispatchMessage(msg, target);
     }
 
-    /* Handle command messages */
+    // Handle command messages
     void MessageReceived(BMessage *message)
     {
         switch (message->what) {
-        /* Handle commands from SDL */
+        // Handle commands from SDL
         case BWIN_SET_TITLE:
             _SetTitle(message);
             break;
@@ -455,28 +455,31 @@ class SDL_BWin : public BWindow
                 delete pendingMessage;
             }
             if (_bitmap != NULL) {
-                if (_SDL_View != NULL && _cur_view == _SDL_View)
-                    _SDL_View->Draw(Bounds());
-                else if (_SDL_GLView != NULL && _cur_view == _SDL_GLView) {
+#ifdef SDL_VIDEO_OPENGL
+                if (_SDL_GLView != NULL && _cur_view == _SDL_GLView) {
                     _SDL_GLView->CopyPixelsIn(_bitmap, B_ORIGIN);
+                } else
+#endif
+                if (_SDL_View != NULL && _cur_view == _SDL_View) {
+                    _SDL_View->Draw(Bounds());
                 }
             }
             break;
         }
         default:
-            /* Perform normal message handling */
+            // Perform normal message handling
             BWindow::MessageReceived(message);
             break;
         }
     }
 
-    /* Accessor methods */
+    // Accessor methods
     bool IsShown() { return _shown; }
     int32 GetID() { return _id; }
     BBitmap *GetBitmap() { return _bitmap; }
     BView *GetCurView() { return _cur_view; }
     SDL_BView *GetView() { return _SDL_View; }
-#if SDL_VIDEO_OPENGL
+#ifdef SDL_VIDEO_OPENGL
     BGLView *GetGLView()
     {
         return _SDL_GLView;
@@ -484,7 +487,7 @@ class SDL_BWin : public BWindow
     Uint32 GetGLType() { return _gl_type; }
 #endif
 
-    /* Setter methods */
+    // Setter methods
     void SetID(int32 id) { _id = id; }
     void LockBuffer() { _buffer_locker->Lock(); }
     void UnlockBuffer() { _buffer_locker->Unlock(); }
@@ -496,16 +499,16 @@ class SDL_BWin : public BWindow
     }
 
   private:
-    /* Event redirection */
+    // Event redirection
     void _MouseMotionEvent(BPoint &where, int32 transit)
     {
         if (transit == B_EXITED_VIEW) {
-            /* Change mouse focus */
+            // Change mouse focus
             if (_mouse_focused) {
                 _MouseFocusEvent(false);
             }
         } else {
-            /* Change mouse focus */
+            // Change mouse focus
             if (!_mouse_focused) {
                 _MouseFocusEvent(true);
             }
@@ -529,55 +532,55 @@ class SDL_BWin : public BWindow
          if true:  SDL_SetCursor(NULL); */
     }
 
-    void _MouseButtonEvent(int32 buttons, Uint8 state)
+    void _MouseButtonEvent(int32 buttons, bool down)
     {
         int32 buttonStateChange = buttons ^ _last_buttons;
 
         if (buttonStateChange & B_PRIMARY_MOUSE_BUTTON) {
-            _SendMouseButton(SDL_BUTTON_LEFT, state);
+            _SendMouseButton(SDL_BUTTON_LEFT, down);
         }
         if (buttonStateChange & B_SECONDARY_MOUSE_BUTTON) {
-            _SendMouseButton(SDL_BUTTON_RIGHT, state);
+            _SendMouseButton(SDL_BUTTON_RIGHT, down);
         }
         if (buttonStateChange & B_TERTIARY_MOUSE_BUTTON) {
-            _SendMouseButton(SDL_BUTTON_MIDDLE, state);
+            _SendMouseButton(SDL_BUTTON_MIDDLE, down);
         }
 
         _last_buttons = buttons;
     }
 
-    void _SendMouseButton(int32 button, int32 state)
+    void _SendMouseButton(int32 button, bool down)
     {
         BMessage msg(BAPP_MOUSE_BUTTON);
         msg.AddInt32("button-id", button);
-        msg.AddInt32("button-state", state);
+        msg.AddBool("button-down", down);
         _PostWindowEvent(msg);
     }
 
     void _MouseWheelEvent(int32 x, int32 y)
     {
-        /* Create a message to pass along to the BeApp thread */
+        // Create a message to pass along to the BeApp thread
         BMessage msg(BAPP_MOUSE_WHEEL);
         msg.AddInt32("xticks", x);
         msg.AddInt32("yticks", y);
         _PostWindowEvent(msg);
     }
 
-    void _KeyEvent(int32 keyCode, const int8 *keyUtf8, const ssize_t &len, int32 keyState)
+    void _KeyEvent(int32 keyCode, const int8 *keyUtf8, const ssize_t &len, bool down)
     {
-        /* Create a message to pass along to the BeApp thread */
+        // Create a message to pass along to the BeApp thread
         BMessage msg(BAPP_KEY);
-        msg.AddInt32("key-state", keyState);
         msg.AddInt32("key-scancode", keyCode);
         if (keyUtf8 != NULL) {
             msg.AddData("key-utf8", B_INT8_TYPE, (const void *)keyUtf8, len);
         }
+        msg.AddBool("key-down", down);
         SDL_Looper->PostMessage(&msg);
     }
 
     void _RepaintEvent()
     {
-        /* Force a repaint: Call the SDL exposed event */
+        // Force a repaint: Call the SDL exposed event
         BMessage msg(BAPP_REPAINT);
         _PostWindowEvent(msg);
     }
@@ -587,7 +590,7 @@ class SDL_BWin : public BWindow
         SDL_Looper->PostMessage(&msg);
     }
 
-    /* Command methods (functions called upon by SDL) */
+    // Command methods (functions called upon by SDL)
     void _SetTitle(BMessage *msg)
     {
         const char *title;
@@ -675,7 +678,7 @@ class SDL_BWin : public BWindow
             Show();
         } else if (_fullscreen) {
 
-        } else if (_prev_frame != NULL) { /* Zoomed */
+        } else if (_prev_frame != NULL) { // Zoomed
             MoveTo(_prev_frame->left, _prev_frame->top);
             ResizeTo(_prev_frame->Width(), _prev_frame->Height());
         }
@@ -708,29 +711,29 @@ class SDL_BWin : public BWindow
         }
     }
 
-    /* Members */
+    // Members
 
     BView *_cur_view;
     SDL_BView *_SDL_View;
-#if SDL_VIDEO_OPENGL
+#ifdef SDL_VIDEO_OPENGL
     BGLView *_SDL_GLView;
     Uint32 _gl_type;
 #endif
 
     int32 _last_buttons;
-    int32 _id;           /* Window id used by SDL_BApp */
-    bool _mouse_focused; /* Does this window have mouse focus? */
+    int32 _id;           // Window id used by SDL_BApp
+    bool _mouse_focused; // Does this window have mouse focus?
     bool _shown;
     bool _inhibit_resize;
 
-    BRect *_prev_frame; /* Previous position and size of the window */
+    BRect *_prev_frame; // Previous position and size of the window
     bool _fullscreen;
     // valid only if fullscreen
     BRect _non_fullscreen_frame;
     bool _bordered;
     bool _resizable;
 
-    /* Framebuffer members */
+    // Framebuffer members
     BLocker *_buffer_locker;
     BBitmap *_bitmap;
 };
@@ -749,6 +752,4 @@ class SDL_BWin : public BWindow
  *                         through a draw cycle.  Occurs when the previous
  *                         buffer provided by DirectConnected() is invalidated.
  */
-#endif /* SDL_BWin_h_ */
-
-/* vi: set ts=4 sw=4 expandtab: */
+#endif // SDL_BWin_h_
